# Mirai-Py

Thanks for the great work of [Mirai](https://github.com/mamoe/mirai).

This python binding relies on [Mirai Console v0.3.1](https://github.com/mamoe/mirai-console/releases/tag/v0.3.1) with [mirai-api-http-1.0.0](https://github.com/mamoe/mirai-api-http/releases/tag/1.0.0) installed.

---

This package is for learning purposes only. For a better experience, see [kuriyama](https://pypi.org/project/kuriyama/).